@@ -15,6 +15,7 @@ log = logging.getLogger('facebook_pages')
 
 PAGES_FANS_USER_ID = getattr(settings, 'FACEBOOK_PAGES_FANS_USER_ID', '')
 
+
 class FacebookPageGraphManager(FacebookGraphManager):
 
     def get_by_slug(self, slug):
@@ -77,6 +78,10 @@ class Page(FacebookGraphIDModel):
 
         super(Page, self).parse(response)
 
+    @property
+    def slug(self):
+        return self.username or self.graph_id
+
     @property
     def wall_posts(self):
         if 'facebook_posts' not in settings.INSTALLED_APPS:
